
class Lowpass(object):
    def __init__(self, tau, ts):
        self._a = 1. / (tau / ts + 1.)
        self._b = tau / ts / (tau / ts + 1.);
        self._last_value = 0.
        self._ready = False

    def get(self):
        return self._last_value

    def filter(self, val):
        if self._ready:
            val = self._a * val + self._b * self._last_value
        else:
            self._ready = True
        self._last_value = val
        return val



import threading
import time


class Timer(object):

    def __init__(self, interval, callback_func, oneshot=False, args=None, kwargs=None):
        self._interval = interval
        self._oneshot = oneshot
        self._f = callback_func
        self._args = args if args is not None else []
        self._kwargs = kwargs if kwargs is not None else {}
        self._timer = None
        self._start_time = None
        self._elapsed_time = None
        self._remaining_time = None

    def _callback(self):
        self._f(*self._args, **self._kwargs)
        if not self._oneshot:
            self.start()
        else:
            self.stop()

    def stop(self):
        if self._timer:
            self._timer.cancel()
            self._elapsed_time = time.time() - self._start_time
            self._remaining_time = self._interval - self._elapsed_time
            self._timer = None

    def start(self, interval=None):
        self._interval = interval if interval is not None else self._interval
        self._timer = threading.Timer(self._interval, self._callback)
        self._start_time = time.time()
        self._timer.start()

    @property
    def elapsed(self):
        return self._elapsed_time

    @property
    def remaining(self):
        return self._remaining_time

    @property
    def running(self):
        return True if self._timer else False



import unittest
from nfiniity_utils.nfiniity_utils.timer import Timer

class TestTimer(unittest.TestCase):

    def timeout(self, name):
        print("Timeout: " + name)

    def test_init(self):
        t = Timer(1, self.timeout, oneshot=True, args=["test_init"])
        self.assertIsNotNone(t)

    def test_start(self):
        t = Timer(1, self.timeout, oneshot=True, args=["test_start"])
        t.start()
        self.assertEqual(t.running, True)

    def test_stop(self):
        t = Timer(1, self.timeout, oneshot=True, args=["test_stop"])
        t.start()
        t.stop()
        self.assertEqual(t.running, False)

if __name__ == '__main__':
    unittest.main()


import setuptools
import nfiniity_utils


with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="nfiniity_utils",
    version=nfiniity_utils.__version__,
    author="Apostolos Georgiadis",
    author_email="apostolos.georgiadis@nfiniity.com",
    description=" Diverse python utilities by nfiniity GmbH",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/apgeorg/nfiniity_utils.git",
    packages=setuptools.find_packages(),
    classifiers=[
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
